@@ -9,7 +9,7 @@
  */
 
 #include "eckit/web/JSONResource.h"
-#include "eckit/parser/JSON.h"
+#include "eckit/log/JSON.h"
 #include "eckit/web/Url.h"
 
 //----------------------------------------------------------------------------------------------------------------------
