@@ -48,6 +48,9 @@ typedef struct dhsdata {
 	char              *address;
 	int               local_port;
 
+	int               callback_port; /* For Kubernetis */
+	char              *callback_host;
+
 	int               csoc; /* Current sockect */
 	int               asoc; /* Accept socket */
 	ulong64           id;
@@ -127,6 +130,11 @@ static option opts[] = {
 	{"local_port","MARS_DHS_LOCALPORT",NULL,"0",t_int,sizeof(int),
 		OFFSET(dhsdata,local_port)},
 
+	{"callback_host","MARS_DHS_CALLBACK_HOST",NULL,NULL,t_str,sizeof(char*),
+		OFFSET(dhsdata,callback_host)},
+
+	{"callback_port","MARS_DHS_CALLBACK_PORT",NULL,"0",t_int,sizeof(int),
+		OFFSET(dhsdata,callback_port)},
 
 	{"obs","MARS_KNOW_OBS",NULL,"0",t_boolean,sizeof(boolean),
 		OFFSET(dhsdata,know_obs)},
@@ -2371,7 +2379,7 @@ static err dhs_send(dhsdata *dhs,request *r,request *e)
 		}
 #endif
 
-	marslog(LOG_INFO,"Calling mars on '%s', callback on %d",dhs->host,port);
+	marslog(LOG_INFO,"Calling mars on '%s', local port is %d",dhs->host,port);
 
 	timer_start(connect_time);
 	dhs->csoc = call_server(dhs->host,dhs->port,dhs->retry);
@@ -2407,9 +2415,18 @@ static err dhs_send(dhsdata *dhs,request *r,request *e)
 	/* Send cb info */
 
 	addr = dhs->address?dhs->address:address;
-	if(mars.show_hosts)
-		if(dhs->address)
-			marslog(LOG_INFO,"Callback at address %s, port %d",addr,port);
+
+	if(dhs->callback_host) {
+		addr = dhs->callback_host;
+	}
+
+	if(dhs->callback_port) {
+		port = dhs->callback_port;
+	}
+
+	if(mars.show_hosts) {
+		marslog(LOG_INFO,"Callback at address %s, port %d",addr,port);
+	}
 
 	stream_write_string(&dhs->s,addr);
 	stream_write_int(&dhs->s,port);
