@@ -1,6 +1,6 @@
 /***************************** LICENSE START ***********************************
 
- Copyright 2012 ECMWF and INPE. This software is distributed under the terms
+ Copyright 2019 ECMWF and INPE. This software is distributed under the terms
  of the Apache License version 2.0. In applying this license, ECMWF does not
  waive the privileges and immunities granted to it by virtue of its status as
  an Intergovernmental Organization or submit itself to any jurisdiction.
@@ -452,7 +452,7 @@ string MvNcAtt::as_string(long n)
         }
     }
 
-    return nullptr;
+    return {};
 }
 
 // Format attribute values in a sensible way
@@ -900,27 +900,27 @@ bool MvNcVar::addAttribute(MvNcAtt* att)
     if (type == NC_BYTE || type == NC_CHAR) {
         const char* vals = (const char*)att->values()->base();
         ret_code =
-            addAttribute(att->name(), att->values()->getNumberOfValues(), vals);
+            addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_SHORT) {
         const short* vals = (const short*)att->values()->base();
         ret_code =
-            addAttribute(att->name(), att->values()->getNumberOfValues(), vals);
+            addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_LONG) {
         const nclong* vals = (const nclong*)att->values()->base();
         ret_code =
-            addAttribute(att->name(), att->values()->getNumberOfValues(), vals);
+            addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_FLOAT) {
         const float* vals = (const float*)att->values()->base();
         ret_code =
-            addAttribute(att->name(), att->values()->getNumberOfValues(), vals);
+            addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
     else if (type == NC_DOUBLE) {
         const double* vals = (const double*)att->values()->base();
         ret_code =
-            addAttribute(att->name(), att->values()->getNumberOfValues(), vals);
+            addAttribute(att->name(), att->values()->getNumberOfValues(), vals, type);
     }
 
     return ret_code;
@@ -1701,19 +1701,26 @@ MvNcVar* MvNetCDF::addVariable(const string& name, int type, int size,
     if (variableExists(name))
         return getVariable(name);
 
+    int* dimIds = nullptr;
+
     // Get dimension info
-    int* dimIds = new int[size];
-    for (int i = 0; i < size; i++)
-        dimIds[i] = dim[i]->id();
+    if (size > 0) {
+        dimIds = new int[size];
+        for (int i = 0; i < size; i++)
+            dimIds[i] = dim[i]->id();
+    }
 
     // Add variable to the netcdf file
     if (!ncFile_->defineMode())
-        return NULL;
+        return nullptr;
 
     int varId;
     int status = nc_def_var(ncId(), name.c_str(), type, size, dimIds, &varId);
     if (status != NC_NOERR) {
-        delete[] dimIds;
+
+        if (dimIds) {
+            delete [] dimIds;
+        }
         return NULL;
     }
 
@@ -1722,7 +1729,9 @@ MvNcVar* MvNetCDF::addVariable(const string& name, int type, int size,
     MvNcVar* tmpvar = new MvNcVar(varId, sname, type, false, this);
     variables_.push_back(tmpvar);
 
-    delete[] dimIds;
+    if (dimIds) {
+        delete [] dimIds;
+    }
 
     return tmpvar;
 }
