@@ -1,6 +1,6 @@
 /***************************** LICENSE START ***********************************
 
- Copyright 2012 ECMWF and INPE. This software is distributed under the terms
+ Copyright 2019 ECMWF and INPE. This software is distributed under the terms
  of the Apache License version 2.0. In applying this license, ECMWF does not
  waive the privileges and immunities granted to it by virtue of its status as
  an Intergovernmental Organization or submit itself to any jurisdiction.
@@ -465,7 +465,7 @@ public:
     }
 
     template <class T>
-    bool addAttribute(const string& name, int nr, T* values)
+    bool addAttribute(const string& name, int nr, T* values, NcType attrType)
     {
         if (!isValid())
             return false;
@@ -474,15 +474,9 @@ public:
             return true;
         }
 
-        // Add attribute to the netcdf file
-        // F      NcBool ret_code = ncVar_->add_att(name.c_str(),nr,values);
-        // ?????? 20190221 Maybe type_ is not correct: it is the type
-        // of the variable, instead of the attributes??? Check later ?????
-
-        int ret_code = nc_put_att(ncId_, id_, name.c_str(), type_, nr, values);
-        if (ret_code == NC_NOERR) {
-            // F        attributes_.push_back( new
-            // MvNcAtt(ncVar_->get_att(attributes_.size() ) ) );
+        // Add attribute to the netcdf file     
+        int ret_code = nc_put_att(ncId_, id_, name.c_str(), attrType, nr, values);
+        if (ret_code == NC_NOERR) {          
             MvNcAtt* attr = new MvNcAtt(ncId_, id_, name);
             attributes_.push_back(attr);
         }
@@ -757,6 +751,10 @@ ncStatus_=nc_get_var_double(ncId_,id_,(double*)&vals.front());
     {
         return nc_put_var_short(ncId_, id_, vals);
     }
+    int putv(const float* vals)
+    {
+        return nc_put_var_float(ncId_, id_, vals);
+    }
     int putv(const double* vals)
     {
         return nc_put_var_double(ncId_, id_, vals);
