@@ -9,18 +9,19 @@
  */
 
 
-
 #include "mir/compare/BufrField.h"
-#include "mir/util/Grib.h"
-#include "eckit/types/Types.h"
 
+#include <iomanip>
 
+#include "eckit/log/Colour.h"
+#include "eckit/log/JSON.h"
 #include "eckit/option/CmdArgs.h"
 #include "eckit/option/SimpleOption.h"
-#include "eckit/parser/JSON.h"
+#include "eckit/types/Types.h"
 #include "eckit/utils/Tokenizer.h"
-#include "eckit/log/Colour.h"
-#include <iomanip>
+
+#include "mir/util/Grib.h"
+
 
 namespace mir {
 namespace compare {
