@@ -141,6 +141,6 @@ CASE("MIR-374") {
 
 
 int main(int argc, char **argv) {
-    return eckit::testing::run_tests(argc, argv, false);
+    return eckit::testing::run_tests(argc, argv);
 }
 
